==> rtap_0.9.5-1.tar.gz: rtap-0.9.5/src/opt/rtap/dijkstra.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

from PyQt4 import QtCore, QtGui
import station
import math

#graph = station.graph

def voisin(S):
    return graph[S].corres
def voisinColor(S):
    return graph[S].corresColor
    
def gps(S):
    return graph[S]['coord']
    
def X(S):
    return graph[S].x()
def Y(S):
    return graph[S].y()
def color(S):
    return graph[S].colorIni.color()

def algo(A,B,G):
    C1, T1 = calc(A,B,G)
    if T1 - int(T1) == 0:
        C2, T2 = calc(B,A,G)
        if T2 - int(T2) != 0:
            C2 , T2 = [], 1000000000.
    else:
        C2 , T2 = [], 1000000000.

    if T1 < T2:
        return C1, T1
    else:
        C2.reverse()
        return C2, T2

def calc(Deb, Fin,G):                
                """
                visit http://en.wikipedia.org/wiki/Dijkstra%27s_algorithm for more information """
#                print 'Dijkstra : %s --> %s'%(Deb,Fin)
                reload(station)
                noeuds = station.station
                graph = G
                
                l__vertexTarget = noeuds[Fin] # get the target
                if True:
                        # -- initialisation
                        # 1. Assign to every node a distance value: set it to zero for our initial node and to infinity for all other nodes.
                        l__queue = []
                        # 2. Mark all nodes as unvisited. Set initial node as current.
                        l__current_vertex = Deb
                        noeuds[l__current_vertex][3] = Deb
                        l__old_vertex = Deb
                        noeuds[l__current_vertex][0] = 0
                        l__visitedVertex = 0
                        
                        l__old_edge = -1
                        # -- end of initialisation
 
                        while l__visitedVertex < len(noeuds):
                                # 3. For current node, consider all its unvisited neighbors and calculate their tentative distance.
                                #print 

                                l__successors = graph[l__current_vertex].corres
                                l__successorsColor = graph[l__current_vertex].corresColor
                                
                                
                                l__old_vertex = noeuds[l__current_vertex][3]
                                
                                if l__successors.count(l__old_vertex) > 0:
                                    l__old_edge = l__successors.index(l__old_vertex)
                                elif l__successors.count(l__old_vertex) == 0:
                                    if len(l__successors) % 2 == 1 and not station.LigneM in l__successorsColor and l__current_vertex != 'Saint-Lazare':
                                        l__old_edge = -2
                                        #print '=== il y a un sens unique'
                                    else:
                                        l__old_edge = -1
                                        

                                #print 'noeud courant', l__current_vertex, 'ancien noeud', l__old_vertex, 'indexé par', l__old_edge

                                for l__successor in l__successors:
                                        #print '** noeud suivant considéré', l__successor
                                        if not noeuds[l__successor][1]:
                                                l__current_edge = l__successors.index(l__successor)
                                                

                                                #if l__successorsColor[l__current_edge] != QtGui.QColor(103,47,143):
                                                l__newTentativeDistance = int(noeuds[l__current_vertex][0] + math.sqrt( (graph[l__current_vertex].x() - graph[l__successor].x())**2 + (graph[l__current_vertex].y() - graph[l__successor].y())**2)) + 60.
                                                #else:
                                                #   l__newTentativeDistance = noeuds[l__current_vertex][0] + math.sqrt( (X(l__current_vertex) - X(l__successor))**2 + (Y(l__current_vertex) - Y(l__successor))**2)*.75
                                                
                                                if graph[l__current_vertex].colorIni.color() == station.LigneM and l__old_edge != -1:

                                                        if l__old_edge == -2:
                                                        
                                                            l__newTentativeDistance +=  00.01
                                                            
                                                        elif l__successorsColor[l__current_edge] != l__successorsColor[l__old_edge]:
                                                            #print '         Pas meme couleur entre les points' , [l__old_vertex, l__current_vertex, l__successor]
                                                            l__newTentativeDistance += 200.
                                                            if l__successorsColor[l__old_edge] in [station.Ligne14,station.RERA,station.RERB,station.RERC,station.RERD,station.RERE] :
                                                                #os.pause()
                                                                l__newTentativeDistance +=  100.
                                                        else:
                                                            #print '         meme couleur entre les points' , [l__old_vertex, l__current_vertex, l__successor]
                                                            l__newTentativeDistance +=  0
                                                
                                                if l__newTentativeDistance < noeuds[l__successor][0]:
                                                        noeuds[l__successor][0] = l__newTentativeDistance
                                                        noeuds[l__successor][2] = noeuds[l__current_vertex][2] + [l__current_vertex]
                                                        
                                                l__queue.append(l__successor)
                                                noeuds[l__successor][3] = l__current_vertex
                                                                                                
                                # 4. When we are done considering all neighbors of the current node, mark it as visited. A visited node will not be checked ever again; its distance recorded now is final and minimal.
                                noeuds[l__current_vertex][1] = True
                                #print l__current_vertex, 'visited'
                                l__visitedVertex += 1
                                if l__current_vertex == Fin:

                                    break
                                # 5. If all nodes have been visited, finish. Otherwise, set the unvisited node with the smallest distance (from the initial node, considering all nodes in graph) as the next "current node" and continue from step 3.
                                
                                while noeuds[l__current_vertex][1]:
                                        l__min = 999999999
                                        i = 0
                                        for l__vertex in l__queue:
                                                if noeuds[l__vertex][0]<l__min:
                                                        
                                                        l__min = noeuds[l__vertex][0]
                                                        l__index = i
                                                i+=1
 

                                        l__current_vertex = l__queue.pop(l__index)

                        noeuds[Fin][2].append(Fin)
                        """try:
                            if noeuds[Fin][2][0][:-4] in noeuds[Fin][2][1][:-4] or noeuds[Fin][2][1][:-4] in noeuds[Fin][2][0][:-4]:
                                print "Doublon au départ!"
                                noeuds[Fin][0] = noeuds[Fin][0] - 1000
                                noeuds[Fin][2].pop(1)
                        except IndexError: 
                            print 'hmm'"""
#                        print 'fini en ', noeuds[Fin][0], 'secondes soit : ', noeuds[Fin][0]/60, 'minutes'#'  et etapes : ' , noeuds[Fin][2]

                        return noeuds[Fin][2] , noeuds[Fin][0]
                else:
#                        print 'target does not exist'
                        return [Deb,Fin]

==> rtap_0.9.6-1.tar.gz: rtap-0.9.6/src/opt/rtap/dijkstra.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

from PyQt4 import QtCore, QtGui
import station
import math

#graph = station.graph

def voisin(S):
    return graph[S].corres
def voisinColor(S):
    return graph[S].corresColor
    
def gps(S):
    return graph[S]['coord']
    
def X(S):
    return graph[S].x()
def Y(S):
    return graph[S].y()
def color(S):
    return graph[S].colorIni.color()

def algo(A,B,G):
    C1, T1 = calc(A,B,G)
    if T1 - int(T1) == 0:
        C2, T2 = calc(B,A,G)
        if T2 - int(T2) != 0:
            C2 , T2 = [], 1000000000.
    else:
        C2 , T2 = [], 1000000000.

    if T1 < T2:
        return C1, T1
    else:
        C2.reverse()
        return C2, T2

def calc(Deb, Fin,G):                
                """
                visit http://en.wikipedia.org/wiki/Dijkstra%27s_algorithm for more information """
                print 'Dijkstra : %s --> %s'%(Deb,Fin)
                reload(station)
                noeuds = station.station
                graph = G
                
                l__vertexTarget = noeuds[Fin] # get the target
                if True:
                        # -- initialisation
                        # 1. Assign to every node a distance value: set it to zero for our initial node and to infinity for all other nodes.
                        l__queue = []
                        # 2. Mark all nodes as unvisited. Set initial node as current.
                        l__current_vertex = Deb
                        noeuds[l__current_vertex][3] = Deb
                        l__old_vertex = Deb
                        noeuds[l__current_vertex][0] = 0
                        l__visitedVertex = 0
                        
                        l__old_edge = -1
                        # -- end of initialisation
 
                        while l__visitedVertex < len(noeuds):
                                # 3. For current node, consider all its unvisited neighbors and calculate their tentative distance.
                                #print 

                                l__successors = graph[l__current_vertex].corres
                                l__successorsColor = graph[l__current_vertex].corresColor
                                
                                
                                l__old_vertex = noeuds[l__current_vertex][3]
                                
                                if l__successors.count(l__old_vertex) > 0:
                                    l__old_edge = l__successors.index(l__old_vertex)
                                elif l__successors.count(l__old_vertex) == 0:
                                    if len(l__successors) % 2 == 1 and not station.LigneM in l__successorsColor and l__current_vertex != 'Saint-Lazare':
                                        l__old_edge = -2
                                        #print '=== il y a un sens unique'
                                    else:
                                        l__old_edge = -1
                                        

                                #print 'noeud courant', l__current_vertex, 'ancien noeud', l__old_vertex, 'indexé par', l__old_edge

                                for l__successor in l__successors:
                                        #print '** noeud suivant considéré', l__successor
                                        if not noeuds[l__successor][1]:
                                                l__current_edge = l__successors.index(l__successor)
                                                

                                                #if l__successorsColor[l__current_edge] != QtGui.QColor(103,47,143):
                                                l__newTentativeDistance = int(noeuds[l__current_vertex][0] + math.sqrt( (graph[l__current_vertex].x() - graph[l__successor].x())**2 + (graph[l__current_vertex].y() - graph[l__successor].y())**2)) + 60.
                                                #else:
                                                #   l__newTentativeDistance = noeuds[l__current_vertex][0] + math.sqrt( (X(l__current_vertex) - X(l__successor))**2 + (Y(l__current_vertex) - Y(l__successor))**2)*.75
                                                
                                                if graph[l__current_vertex].colorIni.color() == station.LigneM and l__old_edge != -1:

                                                        if l__old_edge == -2:
                                                        
                                                            l__newTentativeDistance +=  00.01
                                                            
                                                        elif l__successorsColor[l__current_edge] != l__successorsColor[l__old_edge]:
                                                            #print '         Pas meme couleur entre les points' , [l__old_vertex, l__current_vertex, l__successor]
                                                            l__newTentativeDistance += 200.
                                                            if l__successorsColor[l__old_edge] in [station.Ligne14,station.RERA,station.RERB,station.RERC,station.RERD,station.RERE] :
                                                                #os.pause()
                                                                l__newTentativeDistance +=  100.
                                                        else:
                                                            #print '         meme couleur entre les points' , [l__old_vertex, l__current_vertex, l__successor]
                                                            l__newTentativeDistance +=  0
                                                
                                                if l__newTentativeDistance < noeuds[l__successor][0]:
                                                        noeuds[l__successor][0] = l__newTentativeDistance
                                                        noeuds[l__successor][2] = noeuds[l__current_vertex][2] + [l__current_vertex]
                                                        
                                                l__queue.append(l__successor)
                                                noeuds[l__successor][3] = l__current_vertex
                                                                                                
                                # 4. When we are done considering all neighbors of the current node, mark it as visited. A visited node will not be checked ever again; its distance recorded now is final and minimal.
                                noeuds[l__current_vertex][1] = True
                                #print l__current_vertex, 'visited'
                                l__visitedVertex += 1
                                if l__current_vertex == Fin:

                                    break
                                # 5. If all nodes have been visited, finish. Otherwise, set the unvisited node with the smallest distance (from the initial node, considering all nodes in graph) as the next "current node" and continue from step 3.
                                
                                while noeuds[l__current_vertex][1]:
                                        l__min = 999999999
                                        i = 0
                                        for l__vertex in l__queue:
                                                if noeuds[l__vertex][0]<l__min:
                                                        
                                                        l__min = noeuds[l__vertex][0]
                                                        l__index = i
                                                i+=1
 

                                        l__current_vertex = l__queue.pop(l__index)

                        noeuds[Fin][2].append(Fin)
                        """try:
                            if noeuds[Fin][2][0][:-4] in noeuds[Fin][2][1][:-4] or noeuds[Fin][2][1][:-4] in noeuds[Fin][2][0][:-4]:
                                print "Doublon au départ!"
                                noeuds[Fin][0] = noeuds[Fin][0] - 1000
                                noeuds[Fin][2].pop(1)
                        except IndexError: 
                            print 'hmm'"""
#                        print 'fini en ', noeuds[Fin][0], 'secondes soit : ', noeuds[Fin][0]/60, 'minutes'#'  et etapes : ' , noeuds[Fin][2]

                        return noeuds[Fin][2] , noeuds[Fin][0]
                else:
#                        print 'target does not exist'
                        return [Deb,Fin]
